@@ -9,11 +9,12 @@ logger = logging.getLogger(__name__)
 
 
 class LxExtensionManager:
-    def __init__(self, lx_extensions=[]):
+    def __init__(self, lx_extensions=[], **kwargs):
+        self.crawler = kwargs.get("crawler")
         self.lx_extensions = lx_extensions
-
+        self.depth_limit = self.crawler.settings.getint('DEPTH_LIMIT', None)
     @classmethod
-    def from_crawler(cls, crawler):
+    def from_crawler(cls, crawler, *args, **kwargs):
         settings = crawler.settings
         lx_extensions_cls = [load_object(p) for p in settings.getlist("LX_EXTENSIONS")]
         lx_extensions = []
@@ -22,7 +23,9 @@ class LxExtensionManager:
                 logger.warning(f"Invalid link extractor extension type {str(c)}")
                 continue
             lx_extensions.append(c.from_crawler(crawler))
-        return cls(lx_extensions)
+        kwargs['crawler']=crawler
+        kwargs['lx_extensions']=lx_extensions
+        return cls(*args, **kwargs)
 
     def add_extension(self, lx_extension):
         if not isinstance(lx_extension, LinkExtractorExtension):
@@ -32,10 +35,35 @@ class LxExtensionManager:
             return
         self.lx_extensions.append(lx_extension)
 
+    def _get_min_depth(self, request_depth_limit,depth_limit):
+        if request_depth_limit is None and depth_limit is None:
+            return None
+        if request_depth_limit is None:
+            return depth_limit
+        if depth_limit is None:
+            return request_depth_limit
+        return min(request_depth_limit,depth_limit)
+
+    def _get_int_value(self, my_dict:dict, key:str):
+        value=my_dict.get(key,None)
+        if value is None:
+            return None
+        if isinstance(value, int):
+            return value
+        elif isinstance(value, str):
+            if value.isdigit():
+                return int(value)
+        return None
+
     def extract_links(self, response):
         rules = response.request.meta.get("extractor.rules", None)
         if rules is None or not isinstance(rules, list):
             return []
+        depth=self._get_int_value(response.request.meta,"depth")
+        request_depth_limit=self._get_int_value(response.request.meta,"extractor.depth_limit")
+        min_depth=self._get_min_depth(request_depth_limit,self.depth_limit)
+        if min_depth and depth and int(depth) > min_depth:
+            return []
         link_dict = {}
         for lx_extension in self.lx_extensions:
             links = lx_extension.extract_links(response, rules)
